AndroidLaunchDialog class
Constructors
- AndroidLaunchDialog({Key? key, required Device device, required void onLaunch(AndroidQuickLaunchOption option), required VoidCallback onCancel})
-
const
Properties
- device → Device
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- onCancel → VoidCallback
-
final
- onLaunch → void Function(AndroidQuickLaunchOption option)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< AndroidLaunchDialog> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited