ChangelogDialog class

Constructors

ChangelogDialog({Key? key, required List<ChangelogEntry> entries, required VoidCallback onDismiss})
const

Properties

entries List<ChangelogEntry>
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
onDismiss → VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
inherited
createState() → State<ChangelogDialog>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited