ConfirmDialog class

A simple yes/no confirmation overlay.

Enter confirms; Escape cancels.

Constructors

ConfirmDialog({Key? key, required String title, required String message, required VoidCallback onConfirm, required VoidCallback onCancel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
message String
final
onCancel → VoidCallback
final
onConfirm → VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
createElement() → StatelessElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited