DeviceListComponent class

Constructors

DeviceListComponent({Key? key, required List<Device> devices, bool focused = false, int selectedIndex = 0, int scrollBufferItems = 2, void onSelectionChanged(int)?, void onDeviceLaunchRequested(Device)?, void onDeviceShowOptions(Device)?, void onDeviceShutdownRequested(Device)?, void onDeviceLogcatRequested(Device)?, bool isLoading = false, String loadingMessage = 'Loading devices...', String emptyMessage = 'No devices found'})
const

Properties

devices List<Device>
final
emptyMessage String
final
focused bool
final
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
final
key → Key?
finalinherited
loadingMessage String
final
onDeviceLaunchRequested → void Function(Device)?
final
onDeviceLogcatRequested → void Function(Device)?
final
onDeviceShowOptions → void Function(Device)?
final
onDeviceShutdownRequested → void Function(Device)?
final
onSelectionChanged → void Function(int)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollBufferItems int
final
selectedIndex int
final

Methods

createElement() → StatefulElement
inherited
createState() → State<DeviceListComponent>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited