InputDialog class

Constructors

InputDialog({Key? key, required String title, required String label, String hint = '', String initialValue = '', required void onSubmit(String value), required VoidCallback onCancel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hint String
final
initialValue String
final
key → Key?
finalinherited
label String
final
onCancel → VoidCallback
final
onSubmit → void Function(String value)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

createElement() → StatefulElement
inherited
createState() → State<InputDialog>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited