LoadingState class

Constructors

LoadingState({List<String> spinnerFrames = defaultSpinnerFrames, String? message, Duration duration = defaultDuration, TextStyle style = const TextStyle(fontWeight: FontWeight.dim)})
const

Properties

duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spinnerFrames List<String>
final
style → TextStyle
final

Methods

createElement() → StatefulElement
inherited
createState() → State<LoadingState>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultDuration → const Duration
defaultSpinnerFrames → const List<String>