WelcomeDialog class
Constructors
-
WelcomeDialog({Key? key, required VoidCallback onDismiss})
-
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
key
→ Key?
-
finalinherited
-
onDismiss
→ VoidCallback
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(BuildContext context)
→ Component
-
Describes the part of the user interface represented by this component.
-
createElement()
→ StatelessElement
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited