AppSettings class

Constructors

AppSettings({String themeName = 'dark', String? lastSelectedDeviceId})
const
AppSettings.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastSelectedDeviceId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themeName String
final

Methods

copyWith({String? themeName, String? lastSelectedDeviceId}) AppSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited