Device class

Constructors

Device({required String id, required String name, required DeviceOs os, required String platform, required DeviceState state, required DeviceType type})
const
Device.android({required String id, required String name, required DeviceState state, required DeviceType type})
factory
Device.fromJson(Map<String, dynamic> json)
factory
Device.ios({required String id, required String name, String? platform, required DeviceState state, required DeviceType type})
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
final
isRunning bool
no setter
name String
final
os DeviceOs
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state DeviceState
final
type DeviceType
final

Methods

copyWith({String? id, String? name, DeviceOs? os, String? platform, DeviceState? state, DeviceType? type}) Device
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override