IsolateRequest class

Constructors

IsolateRequest({required int id, required IsolateCommand command, required String executable, List<String> arguments = const [], String? workingDirectory, int? timeoutMs})
const

Properties

arguments → List<String>
final
command → IsolateCommand
final
executable → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs → int?
final
workingDirectory → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited