IsolateResponse class

Constructors

IsolateResponse({required int id, String stdout = '', String stderr = '', int exitCode = -1, String? error})
const

Properties

error → String?
final
exitCode → int
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stderr → String
final
stdout → String
final
success → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited