PluginCommandConfig class
A single runnable command that belongs to a PluginConfig.
Constructors
-
PluginCommandConfig({required String id, required String label, required String command, String? description, List<
String> args = const [], List<DeviceOs> platforms = const [], bool requiresRunning = false, PluginRunMode mode = PluginRunMode.detached, String? shortcut, PluginAvailabilityCheck? availability}) -
const
- PluginCommandConfig.fromMap(Map map)
-
factory
Properties
-
args
→ List<
String> -
final
- availability → PluginAvailabilityCheck?
-
final
- command → String
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- label → String
-
final
- mode → PluginRunMode
-
final
-
platforms
→ List<
DeviceOs> -
final
- requiresRunning → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcut → String?
-
final
Methods
-
matches(
Device? device) → bool -
Whether this command can run against
devicegiven its platform and running-state constraints. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveArgs(
Device? device) → List< String> -
Resolves args by interpolating
{device.*}template variables. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited