PluginConfig class

A plugin loaded from the plugins: section of ~/.simutil/settings.yaml. commands under a shared identity and availability probe.

Constructors

PluginConfig({required String id, required String label, required List<PluginCommandConfig> commands, String? description, bool enabled = true, PluginAvailabilityCheck? availability, String? shortcut})
const
PluginConfig.fromMap(Map map)
factory

Properties

availability PluginAvailabilityCheck?
final
commands List<PluginCommandConfig>
final
description String?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcut String?
final

Methods

commandsFor(Device? device) List<PluginCommandConfig>
Commands available for device after platform/running filtering.
hasCommandsFor(Device? device) bool
Whether at least one command is available for device.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited