PluginRunMode enum

How a plugin command's process is started.

Inheritance
Available extensions

Values

detached → const PluginRunMode

The process runs independently of simutil (e.g. GUI tools like scrcpy).

inherit → const PluginRunMode

The process shares stdio with simutil (blocking CLI tools).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String? raw) PluginRunMode

Constants

values → const List<PluginRunMode>
A constant List of the values in this enum, in order of their declaration.