AdbToolOption enum

Inheritance
Available extensions

Values

connectViaIp → const AdbToolOption
const AdbToolOption(label: 'Connect via IP', description: 'Connect to already-paired device (e.g., 192.168.1.100:5555)')
connectViaPairCode → const AdbToolOption
const AdbToolOption(label: 'Connect via Pair Code', description: 'Pair with 6-digit code (Android 11+)')
connectViaQr → const AdbToolOption
const AdbToolOption(label: 'Connect via QR Code', description: 'Scan QR code for wireless debugging (Android 11+)')

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AdbToolOption>
A constant List of the values in this enum, in order of their declaration.