LogcatHelper class
Parsing, filtering, and path detection for Android logcat lines.
Expects threadtime-style lines:
MM-DD HH:MM:SS.mmm PID TID L tag : message
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
firstPath(
String line) → String? -
lineMatchesFilter(
String line, String filter) → bool -
looksLikeCrash(
String line) → bool -
Java
FATAL EXCEPTION, nativeFatal signal, tombstone header, orFlevel. -
parseLevel(
String line) → LogcatLevel