CommandMenuDialog class
Constructors
-
CommandMenuDialog({Key? key, required String title, required List<
PluginCommandConfig> commands, required void onSelect(PluginCommandConfig command), required VoidCallback onCancel}) -
const
Properties
-
commands
→ List<
PluginCommandConfig> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- onCancel → VoidCallback
-
final
- onSelect → void Function(PluginCommandConfig command)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< CommandMenuDialog> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited