MenuOptionRow class
Constructors
- MenuOptionRow({Key? key, required String label, required bool isSelected, String? description, String? shortcut})
-
const
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected → bool
-
final
- key → Key?
-
finalinherited
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcut → String?
-
final
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → StatelessElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited