PluginMenuDialog class
Constructors
-
PluginMenuDialog({Key? key, required List<
PluginConfig> plugins, required void onSelect(PluginConfig plugin), required VoidCallback onCancel}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- onCancel → VoidCallback
-
final
- onSelect → void Function(PluginConfig plugin)
-
final
-
plugins
→ List<
PluginConfig> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< PluginMenuDialog> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited