AndroidDeviceService class

Implemented types

Constructors

AndroidDeviceService(CommandExec _exec)
const

Properties

adbPath String
no setter
emulatorPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connectDevice(String host) Future<AdbConnectResult>
disconnectDevice(String host) Future<bool>
enableTcpIp(String serial, {int port = 5555}) Future<bool>
getAndroidHome() String
getDeviceIpAddress(String serial) Future<String?>
getPhysicalDevices() Future<List<Device>>
override
getSimulators() Future<List<Device>>
override
getWirelessPairingInfo(String serial) Future<WirelessPairingInfo?>
isAvailable() Future<bool>
override
launchDevice({required String deviceId, List<String> additionalArgs = const []}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pairDevice(String host, String pairingCode) Future<AdbConnectResult>
shutdownSimulator({required String deviceId}) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited