WirelessPairingInfo class

Constructors

WirelessPairingInfo({required String deviceIp, required int defaultPort, required bool supportsWirelessDebugging})
const

Properties

defaultPort int
final
deviceIp String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsWirelessDebugging bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited