AppStateServiceImpl class

Implemented types

Constructors

AppStateServiceImpl({String? stateFilePath})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<AppState>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(AppState state) Future<void>
toString() String
A string representation of this object.
inherited
update(AppState updater(AppState)) Future<AppState>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited