DeviceService class abstract

Implementers

Constructors

DeviceService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPhysicalDevices() Future<List<Device>>
getSimulators() Future<List<Device>>
isAvailable() Future<bool>
launchDevice({required String deviceId, List<String> additionalArgs = const []}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdownSimulator({required String deviceId}) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited