IOSDeviceService class

Implemented types

Constructors

IOSDeviceService(CommandExec _exec)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

bootSimulator(String udid) Future<bool>
getPhysicalDevices() Future<List<Device>>
override
getSimulators() Future<List<Device>>
override
isAvailable() Future<bool>
override
launchDevice({required String deviceId, List<String> additionalArgs = const []}) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSimulatorApp(String uuid) Future<void>
shutdownSimulator({required String deviceId}) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractPlatformName(String runtime) String
Derives a human-readable platform name from a simctl runtime key, e.g. com.apple.CoreSimulator.SimRuntime.iOS-17-2 -> iOS 17.2.
parsePhysicalDevices(Map<String, dynamic> json) List<Device>
Parses the JSON written by xcrun devicectl list devices -j into devices. Pure function (no I/O) so it is unit-testable on any platform.
parseSimulators(String jsonStr) List<Device>
Parses the JSON output of xcrun simctl list devices -j into devices. Pure function (no I/O) so it is unit-testable on any platform.