pluginsForDevice abstract method
Plugins that expose at least one command runnable for device.
Implementation
List<PluginConfig> pluginsForDevice(Device? device);
Plugins that expose at least one command runnable for device.
List<PluginConfig> pluginsForDevice(Device? device);