load method
Reads and parses the config file, creating a default one if missing.
Implementation
@override
Future<List<PluginConfig>> load() async {
await ensureConfigFile(_configPath);
return _parseFile(File(_configPath));
}
Reads and parses the config file, creating a default one if missing.
@override
Future<List<PluginConfig>> load() async {
await ensureConfigFile(_configPath);
return _parseFile(File(_configPath));
}