pluginsForDevice method
Plugins that expose at least one command runnable for device.
Implementation
@override
List<PluginConfig> pluginsForDevice(Device? device) =>
_plugins.where((plugin) => plugin.hasCommandsFor(device)).toList();
Plugins that expose at least one command runnable for device.
@override
List<PluginConfig> pluginsForDevice(Device? device) =>
_plugins.where((plugin) => plugin.hasCommandsFor(device)).toList();