reload method
Re-reads the config file from disk, refreshing the cache.
Implementation
@override
Future<List<PluginConfig>> reload() => _parseFile(File(_configPath));
Re-reads the config file from disk, refreshing the cache.
@override
Future<List<PluginConfig>> reload() => _parseFile(File(_configPath));