PluginRunnerServiceImpl class

Implemented types

Constructors

PluginRunnerServiceImpl(CommandExec _commandExec)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAvailable(PluginConfig plugin, PluginCommandConfig command) Future<bool>
Whether the underlying executable for plugin/command is installed.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(PluginCommandConfig command, Device? device) Future<PluginRunResult>
Launches command for device, resolving argument templates.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited