SettingsService class abstract

Implementers

Constructors

SettingsService()

Properties

configFilePath → String
Absolute path to the unified config file (~/.simutil/settings.yaml).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() → Future<AppSettings>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInEditor() → Future<void>
Opens configFilePath in the OS default application.
save(AppSettings settings) → Future<void>
toString() → String
A string representation of this object.
inherited
update(AppSettings updater(AppSettings)) → Future<AppSettings>

Operators

operator ==(Object other) → bool
The equality operator.
inherited