WifiDiscoveryService class abstract

Implementers

Constructors

WifiDiscoveryService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watchPairingDevices() Stream<WifiPairingDevice>
Continuously watches for ADB pairing endpoints via mDNS (_adb-tls-pairing._tcp). Emits each newly discovered device as it is found. Cancel the subscription to stop scanning.

Operators

operator ==(Object other) bool
The equality operator.
inherited