PinCodeFields class
Constructors
-
PinCodeFields({required String label, required bool groupFocused, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, double spacing = 1.0, double cellSpacing = 1.0, required List<
TextEditingController> pinControllers, required int focusedPinIndex, required void onPinChanged(int index, String value), required bool onPinKeyEvent(int index, KeyboardEvent event), required VoidCallback onSubmitted}) -
const
Properties
- cellSpacing → double
-
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- focusedPinIndex → int
-
final
- groupFocused → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- label → String
-
final
- onPinChanged → void Function(int index, String value)
-
final
- onPinKeyEvent → bool Function(int index, KeyboardEvent event)
-
final
- onSubmitted → VoidCallback
-
final
-
pinControllers
→ List<
TextEditingController> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
final
Methods
-
build(
BuildContext context) → Component - Describes the part of the user interface represented by this component.
-
createElement(
) → StatelessElement -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited