SimutilTheme class
Properties
- background → Color
-
no setter
- body → TextStyle
-
no setter
- bold → TextStyle
-
no setter
- data → TuiThemeData
-
no setter
- dimmed → TextStyle
-
no setter
- error → Color
-
no setter
- errorStyle → TextStyle
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → TextStyle
-
no setter
- muted → TextStyle
-
no setter
- onBackground → Color
-
no setter
- onSurface → Color
-
no setter
- outline → Color
-
no setter
- outlineVariant → Color
-
no setter
- primary → Color
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondary → Color
-
no setter
- sectionHeader → TextStyle
-
no setter
- selected → TextStyle
-
no setter
- statusRunning → TextStyle
-
no setter
- statusStopped → TextStyle
-
no setter
- success → Color
-
no setter
- successStyle → TextStyle
-
no setter
- surface → Color
-
no setter
- warning → Color
-
no setter
- warningStyle → TextStyle
-
no setter
Methods
-
dialogPanel(
String title) → BoxDecoration -
focusedPanel(
String title) → BoxDecoration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unfocusedPanel(
String title) → BoxDecoration
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → SimutilTheme -
resolveTheme(
String name) → TuiThemeData