PluginCommandRef class
Pairs a PluginConfig with one of its PluginCommandConfigs, used when a command is resolved via shortcut or after a two-step selection.
Constructors
- PluginCommandRef({required PluginConfig plugin, required PluginCommandConfig command})
-
const
Properties
- command → PluginCommandConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- plugin → PluginConfig
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited