IOSDeviceService class
- Implemented types
Constructors
- IOSDeviceService(CommandExec _exec)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bootSimulator(
String udid) → Future< bool> -
getPhysicalDevices(
) → Future< List< Device> > -
override
-
getSimulators(
) → Future< List< Device> > -
override
-
isAvailable(
) → Future< bool> -
override
-
launchDevice(
{required String deviceId, List< String> additionalArgs = const []}) → Future<void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openSimulatorApp(
String uuid) → Future< void> -
shutdownSimulator(
{required String deviceId}) → Future< bool> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited