ServiceLocator class
Properties
- adbService → AndroidDeviceService
-
latefinal
- commandExec → CommandExec
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolateRunner → IsolateRunner
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingsService → SettingsService
-
latefinal
- simctlService → IOSDeviceService
-
latefinal
Methods
-
dispose(
) → Future< void> -
init(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ServiceLocator
-
no setter