SettingsService class

Settings are stored at ~/.simutil/settings.yaml.

Constructors

SettingsService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<AppSettings>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(AppSettings settings) Future<void>
toString() String
A string representation of this object.
inherited
update(AppSettings updater(AppSettings)) Future<AppSettings>

Operators

operator ==(Object other) bool
The equality operator.
inherited