SettingsServiceImpl class

Settings are stored at ~/.simutil/settings.yaml.

Implemented types

Constructors

SettingsServiceImpl()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<AppSettings>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(AppSettings settings) Future<void>
override
toString() String
A string representation of this object.
inherited
update(SettingsUpdater updater) Future<AppSettings>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited