SettingsServiceImpl class

Settings are stored at ~/.simutil/settings.yaml alongside the plugins: section in the same file.

Implemented types

Constructors

SettingsServiceImpl(CommandExec _exec, {String? settingsFilePath})

Properties

configFilePath String
Absolute path to the unified config file (~/.simutil/settings.yaml).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load() Future<AppSettings>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openInEditor() Future<void>
Opens configFilePath in the OS default application.
override
save(AppSettings settings) Future<void>
override
toString() String
A string representation of this object.
inherited
update(SettingsUpdater updater) Future<AppSettings>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited