menu
simutil package
documentation
services/wifi_discovery_service.dart
WifiDiscoveryService class
WifiDiscoveryService class
dark_mode
light_mode
WifiDiscoveryService
class
abstract
Implementers
MdnsWifiDiscoveryService
Constructors
WifiDiscoveryService
()
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
watchPairingDevices
(
)
→
Stream
<
WifiPairingDevice
>
Continuously watches for ADB pairing endpoints via mDNS (
_adb-tls-pairing._tcp
). Emits each newly discovered device as it is found. Cancel the subscription to stop scanning.
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
simutil package
documentation
services/wifi_discovery_service
WifiDiscoveryService class
wifi_discovery_service library